@@ -725,8 +725,10 @@ class Sf:
             
             combined_row = pd.DataFrame(pd.concat([x_info, x_data], axis=0)).T
             combined_metadata.append(combined_row)
-
-        combined_result_df = pd.concat(combined_metadata, axis=0).reset_index(drop=True)
+        if len(combined_result_df) > 1:
+            combined_result_df = pd.concat(combined_metadata, axis=0).reset_index(drop=True)
+        else:
+            combined_result_df.reset_index(drop=True, inplace=True)
         
         return combined_result_df
 
@@ -1477,7 +1479,7 @@ class Sf:
         else:
             raise Exception('API error when calling %s : %s' % (r.url, r.content))
         
-    def grouper(iterable, n, *, incomplete='fill', fillvalue=None):
+    def grouper(self, iterable, n, *, incomplete='fill', fillvalue=None):
         "Collect data into non-overlapping fixed-length chunks or blocks"
         # grouper('ABCDEFG', 3, fillvalue='x') --> ABC DEF Gxx
         # grouper('ABCDEFG', 3, incomplete='strict') --> ABC DEF ValueError
